from abstractgameunit import AbstractGameUnit

class OrcRider(AbstractGameUnit):
    """Class that represents the game character Orc Rider"""
    def __init__(self, name=''):
        super().__init__(name=name)
        self.max_hp = 30
        self.health_meter = self.max_hp
        self.unit_type = 'enemy'
        self.hut_number = 0

    def info(self):
        """Print basic information about this character"""
        print("Grrr..I am an Orc Wolf Rider. Don't mess with me.")




class GameUnitError(Exception):
    """Custom exceptions class for the `AbstractGameUnit` and its subclasses"""
    def __init__(self, message='', code=000):
        super().__init__(message)
        self.error_message = '~'*50 + '\n'

        # Alternative approach is to subclass GameUnitError
        self.error_dict = {
            000: "ERROR-000: Unspecified Error!",
            101: "ERROR-101: Health Meter Problem!",
            102: "ERROR-102: Attack issue! Ignored",
        }
        try:
            self.error_message += self.error_dict[code]
        except KeyError:
            self.error_message += self.error_dict[000]
        self.error_message += '\n' + '~'*50



import random
from abc import ABC, abstractmethod
from gameuniterror import GameUnitError
from gameutils import print_bold, weighted_random_selection

class AbstractGameUnit(ABC):
    """An abstract base class for creating various game characters"""
    def __init__(self, name=''):
        self.name = name
        self.max_hp = 0
        self.health_meter = 0
        self.enemy = None
        self.unit_type = None

    @abstractmethod
    def info(self):
        """Information on the unit (MUST be overridden in subclasses)"""
        pass

    def attack(self, enemy):
        """The main logic to determine injured unit and amount of injury"""
        if not enemy:
            print("No enemy to attack")
        else:
            injured_unit = weighted_random_selection(self, enemy)
            injury = random.randint(10, 15)
            injured_unit.health_meter = max(injured_unit.health_meter - injury, 0)
            print("ATTACK! ", end='')
            self.show_health(end='  ')
            enemy.show_health(end='  ')
    
    def heal(self, heal_by=2, full_healing=True):
        """Heal the unit replenishing all the hit points"""
        if self.health_meter == self.max_hp:
            return
        
        if full_healing:
            self.health_meter = self.max_hp
        else:
            self.health_meter += heal_by
        
        if self.health_meter > self.max_hp:
            raise GameUnitErrors("health_meter > max_hp!")
        
        print_bold("You are HEALED!", end=' ')
        self.show_health(bold=True)

    def reset_health_meter(self):
        """Reset the `health_meter` (assing default hit points)"""
        self.health_meter = self.max_hp

    def show_health(self, bold=False, end='\n'):
        """Show the remaining hit points of the player and the enemy"""
        msg = "Health: {0:s} {1:d}".format(self.name, self.health_meter)
            
        if bold:
            print_bold(msg, end=end)
        else:
            print(msg, end=end)




import random

def weighted_random_selection(obj1, obj2):
    """Randomly select between two objects based on assigned 'weight'"""
    selection = random.choices([id(obj1), id(obj2)], weights=[0.3, 0.7])
    if selection[0] == id(obj1):
        return obj1
    return obj2

def print_bold(msg, end='\n'):
    """Print a desired messsage in bold"""
    print("\033[1m" + msg + "\033[0m", end=end)




import sys
import os

current_path = os.path.dirname(os.path.abspath(__file__))
sys.path.append(current_path)

# optionally print the sys.path for debugging
print("in __init__.py sys.path:\n {0:s}".format(':'.join(sys.path)))





import random
from hut import Hut
from knight import Knight
from orcrider import OrcRider
from gameutils import print_bold


class AttackOfTheOrcs(object):
    """Main class to play Attack of The Orcs game"""
    def __init__(self):
        self.huts = []
        self.player = None

    def get_occupants(self):
        """Return a list of occupant types for all huts."""
        return [x.get_occupant_type() for x in self.huts]

    def show_game_mission(self):
        """Print the game mission in the console"""
        print_bold("Mission:")
        print("  1. Fight with the enemy.")
        print("  2. Bring all the huts in the village under your control")
        print("---------------------------------------------------------\n")

    def _process_user_choice(self):
        """Process the user input for choice of hut to enter"""
        verifying_choice = True
        idx = 0
        print("Current occupants: {0:s}".format(', '.join(self.get_occupants())))
        while verifying_choice:
            user_choice = input("Choose a hut number to enter (1-5): ")
            
            # Handling Exceptions block
            try:
                idx = int(user_choice)
                assert idx >  0

            except ValueError as e:
                print("Invalid input, args: {0:s}".format(', '.join(e.args)))
                continue
            except AssertionError as e:
                print("Number should be in the range 1-5. Try again")
                
            try:
                if self.huts[idx-1].is_acquired:
                    print("You have already acquired this hut. Try another one.\n"
                          "<INFO: You can NOT get healed in already acquired hut.>")
                else:
                    verifying_choice = False
            except IndexError as e:
                print("Number should be in the range 1-5. Try again")
        return idx

    def _occupy_huts(self):
        """Randomly occupy the huts with one of the options (friend, enemy or 'None')"""
        choice_lst = ['friend', 'enemy', None]
        for i in range(5):
            computer_choice = random.choice(choice_lst)
            if computer_choice == 'enemy':
                name = 'enemy-' + str(i+1)
                self.huts.append(Hut(i+1, OrcRider(name)))
            elif computer_choice == 'friend':
                name = 'knight-' + str(i+1)
                self.huts.append(Hut(i+1, Knight(name)))
            else:
                self.huts.append(Hut(i+1, computer_choice))

    def play(self):
        """
        Workhorse method to play the game.

        Controls the high level logic to play the game. this is called from
        the main program to begin the game execution.
        """
        self.player = Knight()
        self._occupy_huts()
        acquired_hut_counter = 0

        self.show_game_mission()
        self.player.show_health(bold=True)

        while acquired_hut_counter < 5:
            idx = self._process_user_choice()
            self.player.acquire_hut(self.huts[idx-1])

            if self.player.health_meter <= 0:
                print_bold("YOU LOSE :( Better luck next time")
                break

            if self.huts[idx-1].is_acquired:
                acquired_hut_counter += 1

        if acquired_hut_counter == 5:
            print_bold("Congratulations! YOU WIN!!!")

if __name__ == '__main__':
    game = AttackOfTheOrcs()
    game.play()



import setuptools

with open('README', 'r') as f:
    readme = f.read()

setuptools.setup(
    name='gamepkg-jean',
    version='2.0.1',
    packages=['wargame'],
    url='https://pypi.org/legacy/gamepkg-jean',
    license='LICENSE.txt',
    description='game pkg real',
    long_description=readme,
    author='jeancarlo',
    author_email='jeantardelli@gmail.com',
    python_requires='>=3',
    )



from abstractgameunit import AbstractGameUnit
from gameutils import print_bold

class Knight(AbstractGameUnit):
    """
    Class that represents the game character 'Knight'

    The player instance in the game is aKnight instance. Other Knight
    instances are considered as 'friends' of the player and is indicated
    by the attribute `self.unit_type`.
    """
    def __init__(self, name='Sir Foo'):
        super().__init__(name=name)
        self.max_hp = 40
        self.health_meter = self.max_hp
        self.unit_type = 'friend'

    def info(self):
        """Print basic information about this character"""
        print("I am a Knight!")

    def acquire_hut(self, hut):
        """Fight the combat (command line) to acquire the hut"""
        print_bold("Entering hut {0:d}...".format(hut.number), end=' ')
        is_enemy = (isinstance(hut.occupant, AbstractGameUnit) and
                    hut.occupant.unit_type == 'enemy')
        continue_attack = 'y'

        if is_enemy:
            self.enemy = hut.occupant
            self.show_health(bold=True, end=' ')
            self.enemy.show_health(bold=True, end=' ')
            while continue_attack:
                try:
                    continue_attack = input(".......continue attack? (y/n): ")
                    assert continue_attack == 'y' or continue_attack == 'n'
                except AssertionError:
                    print("Please, select either 'y' for attack or 'n' to run away")
                    continue

                if continue_attack == 'n':
                    self.run_away()
                    break

                self.attack(self.enemy)

                if self.enemy.health_meter <= 0:
                    print("")
                    hut.acquired(self)
                    break
                if self.health_meter <=0:
                    print("")
                    break
        else:
            if hut.get_occupant_type() =='unnocupied':
                print_bold("Hut is unoccupied")
            else:
                print_bold("Friend sighted!")
            hut.acquired(self)
            self.heal()

    def run_away(self):
        """Abandon the battle"""
        print_bold("RUNNING AWAY...")
        self.enemy = None



from gameutils import print_bold

class Hut(object):
    """Class to create hut object(s) in the game Attack of the Orcs"""
    def __init__(self, number, occupant):
        self.number = number
        self.occupant = occupant
        self.is_acquired = False

    def acquired(self, new_occupant):
        """Update the occupant of this hut"""
        self.occupant = new_occupant
        self.is_acquired = True
        print_bold("GOOD JOB! Hut {0:d} acquired".format(self.number))

    def get_occupant_type(self):
        """Return a string giving info on the hut occupant"""
        if self.is_acquired:
            occupant_type = 'ACQUIRED'
        elif self.occupant is None:
            occupant_type = 'unoccupied'
        else:
            occupant_type = self.occupant.unit_type

        return occupant_type

